Comment

Struct Comment 

pub struct Comment { /* private fields */ }
Structure for containing the CommentKind and the Span for a comment

Implementations

Source

impl Comment

pub const fn new(kind: CommentKind, span: Span) -> Self

Method for making a new comment

Parameters
  • kind where the type of comment is passed as a CommentKind
  • span where the Span of the comment is passed
pub const fn kind(&self) -> &CommentKind

Getter method to get the CommentKind

pub const fn span(&self) -> &Span

Getter method to get the Span of the comment

pub fn text(&self) -> &str

Getter method that will return the comment content as a str, regardless of CommentKind