Module docs

Module docs 

Convert parsed SQL + extracted comments into structured documentation types.

Structs

ColumnDoc
Structure for containing the name of the Column and an Option for the comment as a String
SqlFileDoc
Structure for containing the docs for every Table in an .sql file as a Vec of TableDoc
TableDoc
Structure for containing the name of the Table, an Option for if the table has a schema, an Option for the comment as a String, and a Vec of ColumnDoc contained in the table