pub struct Comment { /* private fields */ }Expand description
Structure for containing the CommentKind and the Span for a comment
Implementations
Sourceimpl Comment
impl Comment
Sourcepub const fn new(kind: CommentKind, span: Span) -> Self
pub const fn new(kind: CommentKind, span: Span) -> Self
Method for making a new comment
Parameters
kindwhere the type of comment is passed as aCommentKindspanwhere theSpanof the comment is passed
Sourcepub const fn kind(&self) -> &CommentKind
pub const fn kind(&self) -> &CommentKind
Getter method to get the CommentKind
Sourcepub fn text(&self) -> &str
pub fn text(&self) -> &str
Getter method that will return the comment content as a str,
regardless of CommentKind